@@ -48,8 +48,11 @@ AH_JOB *AH_Job_Tan_new(AB_PROVIDER *pro, AB_USER *u, int process, int jobVersion
   dbParams=AH_Job_GetParams(j);
   assert(dbParams);
 
-  GWEN_DB_SetIntValue(dbArgs, GWEN_DB_FLAGS_OVERWRITE_VARS, "process", process);
-  if (process==1 || process==2)
+  if (process=='S')
+    GWEN_DB_SetCharValue(dbArgs, GWEN_DB_FLAGS_OVERWRITE_VARS, "process", "S");
+  else
+    GWEN_DB_SetIntValue(dbArgs, GWEN_DB_FLAGS_OVERWRITE_VARS, "process", process);
+  if (process==1 || process==2 || process=='S')
     GWEN_DB_SetCharValue(dbArgs, GWEN_DB_FLAGS_OVERWRITE_VARS, "moreTans", "N");
 
   /* set tanmedium id (if any) */
@@ -115,7 +118,7 @@ int AH_Job_Tan_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx)
     if (dbTanResponse) {
       const char *s;
 
-      DBG_NOTICE(AQHBCI_LOGDOMAIN, "Got a TAN response");
+      DBG_INFO(AQHBCI_LOGDOMAIN, "Got a TAN response");
       if (GWEN_Logger_GetLevel(0)>=GWEN_LoggerLevel_Debug)
         GWEN_DB_Dump(dbTanResponse, 2);
 
